;;; Second Version of Japaneese Bees.
;;; Ilias Sakellariou, 2014
;;; JSXM Version.


__includes ["state-x-machines-emotions.nls" "x-bees.nls"  "x-hornets.nls" ]
globals [dead-bees max-trans]
patches-own [temp]

breed [bees bee]
breed [hornets hornet]


bees-own [active-states active-states-code active-machines active-machine-names memory percept emotion x-msg]
hornets-own [active-states active-states-code active-machines active-machine-names memory percept emotion] ;;

;;;;;;;;;;;;;;;;;;;;;; setup
to setup
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  clear-all
  reset-ticks 
  random-seed experiment-number
  setup-patches
  setup-bees
  setup-hornets
  set dead-bees 0
end 

;;; setting the initial temperature of the environment
to setup-patches
  ask patches [set temp original_temp]
end 


to run-multiple
  set experiment-number random 100
  setup
  while [[not (x-mem-value "dead")] of one-of hornets and count bees > 2] [run-experiment]
  repeat 10 [run-experiment]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to run-experiment
  tick
  set max-trans 0
  diffuse temp 0.1
  ask patches [set pcolor 120 + (temp - original_temp) * (10 / (51 - original_temp))]
   ;; ask patches with [temp > original_temp] [diffuse temp 0.1]
  ;ask bees with [state = "killed"] [set dead-bees dead-bees + 1 die]
  ask hornets [run-x-cycle-hornets]
  ask bees [run-x-cycle-bees]
 ; do-plotting
end 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;; utilities
to-report temp-around-hornet
  report ifelse-value (any? hornets) 
    [[temp] of one-of hornets ]
    [0]
end

to-report live-bees
  report count bees
end

to color-indication
   if current-state-name#sm = "workInHive" [set color yellow]
   if current-state-name#sm = "inAlert" [set color green]
   if current-state-name#sm = "approachingHornet" [set color violet]
   if current-state-name#sm = "attacking" [set color red]
   if current-state-name#sm = "deadByHeat" [set color brown]
   if current-state-name#sm = "movingAround" [set color yellow]
   if current-state-name#sm = "killingBees" [set color orange]
end 


to rand-xy-co
  let x 0
  let y 0
  loop [ 
    set x random-pxcor 
    set y random-pycor 
    if not any? turtles-on patch x y and not (abs x < 4 and abs y < 4) [setxy x y stop]
  ]
end  

to mark-area
   ask patches in-radius radius [set plabel "+"]
end

to unmark-area
  ask patches in-radius radius [set plabel ""]
end
@#$#@#$#@
GRAPHICS-WINDOW
533
11
1199
698
20
20
16.0
1
10
1
1
1
0
0
0
1
-20
20
-20
20
1
1
1
ticks
30.0

BUTTON
15
16
84
68
Set Up
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
18
114
190
147
num-bees
num-bees
0
500
250
5
1
bees
HORIZONTAL

BUTTON
88
16
174
68
Run Once
run-experiment
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
178
16
299
68
Run Continuesly
run-experiment
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
17
584
180
617
show-x-labels?
show-x-labels?
1
1
-1000

SWITCH
17
620
181
653
show-x-input?
show-x-input?
1
1
-1000

SLIDER
19
179
191
212
radius
radius
0
30
6
1
1
distance
HORIZONTAL

SLIDER
204
117
383
150
original_temp
original_temp
25
40
30
1
1
C
HORIZONTAL

SLIDER
204
239
383
272
diffuse-rate
diffuse-rate
0
0.5
0.3
0.01
1
NIL
HORIZONTAL

SLIDER
204
178
383
211
temp-increase
temp-increase
0
2
0.4
0.05
1
C
HORIZONTAL

TEXTBOX
209
80
368
111
Temperature Controls\nInitial Temparature.\n
11
0.0
1

SLIDER
20
239
192
272
killing_rate
killing_rate
0
100
20
1
1
%
HORIZONTAL

MONITOR
279
329
437
374
Hornet's Temperature
temp-around-hornet
2
1
11

MONITOR
279
379
437
424
Dead Bees
dead-bees
17
1
11

PLOT
18
329
276
510
Temperature Around Hornet
Time
Temp
0.0
50.0
28.0
50.0
true
false
"" ""
PENS
"temp-of-hornet" 1.0 0 -2674135 true "" "ifelse (any? hornets) \n  [plot [temp] of one-of hornets]\n  [plot 0]"

SWITCH
16
656
179
689
show-x-output?
show-x-output?
1
1
-1000

SLIDER
304
35
479
68
experiment-number
experiment-number
0
100
4
1
1
NIL
HORIZONTAL

BUTTON
207
582
416
615
Random Run
run-multiple
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
207
621
418
654
Random Runs (Mupltiple)
run-multiple
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
304
13
493
31
Setting Specific Initial Conditions
11
0.0
1

TEXTBOX
20
98
170
116
Number of Bees 
11
0.0
1

TEXTBOX
21
221
171
239
Hornet Killing Probability
11
0.0
1

TEXTBOX
209
158
416
176
Increase by each bee flap of wings.
11
0.0
1

TEXTBOX
209
217
359
235
Temp diffuse rate
11
0.0
1

TEXTBOX
20
158
170
176
Radius of Bee Perception
11
0.0
1

TEXTBOX
19
524
177
580
Debugging\nShow input,output and state change (x-labels) of Bees
11
0.0
1

TEXTBOX
209
541
359
569
Random Run and Multiple Random Runs
11
0.0
1

TEXTBOX
213
655
363
697
Sometimes it after clicking it will take a while to stop. Please wait.
11
104.0
1

SWITCH
1251
456
1357
489
check?
check?
0
1
-1000

MONITOR
1253
499
1333
544
NIL
max-trans
17
1
11

PLOT
1249
297
1565
447
Max Transitions
ticks
Trans
0.0
5.0
0.0
5.0
true
false
"" "ifelse max-trans = 1 \n  [set-plot-pen-color green]\n  [set-plot-pen-color red]"
PENS
"default" 1.0 0 -16777216 true "" "plot max-trans"

OUTPUT
1250
15
1582
294
11

SLIDER
20
285
192
318
hornet-agility
hornet-agility
0
100
20
1
1
%
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

A simulation of the attack of a hornet and the defence of the Japanese Bee. 

## HOW IT WORKS

Nicely, but a bit add-hoc.

## HOW TO USE IT

## THINGS TO NOTICE

Color Coding

Bees  
yellow (happy bee) Working in Hive  
blue Approaching Hornet  
red Attacking Hornet  
Brown Killed by Hornet

Hornets  
brown deadByHeat (A dead hornet is a good hornet)  
yellow movingAround  
pink   "killingBees" (Die by a pink hornet)

## THINGS TO TRY

## EXTENDING THE MODEL

Moving the Hornet Around.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

## CREDITS AND REFERENCES

Ilias Sakellariou, Petros Kefalas, Ioanna Stamatopoulou, George Eleftherakis
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -1184463 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -7500403 true true 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7500403 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bee 2
true
0
Polygon -1184463 true false 195 150 105 150 90 165 90 225 105 270 135 300 165 300 195 270 210 225 210 165 195 150
Rectangle -16777216 true false 90 165 212 185
Polygon -16777216 true false 90 207 90 226 210 226 210 207
Polygon -16777216 true false 103 266 198 266 203 246 96 246
Polygon -6459832 true false 120 150 105 135 105 75 120 60 180 60 195 75 195 135 180 150
Polygon -6459832 true false 150 15 120 30 120 60 180 60 180 30
Circle -16777216 true false 105 30 30
Circle -16777216 true false 165 30 30
Polygon -7500403 true true 120 90 75 105 15 90 30 75 120 75
Polygon -16777216 false false 120 75 30 75 15 90 75 105 120 90
Polygon -7500403 true true 180 75 180 90 225 105 285 90 270 75
Polygon -16777216 false false 180 75 270 75 285 90 225 105 180 90
Polygon -7500403 true true 180 75 180 90 195 105 240 195 270 210 285 210 285 150 255 105
Polygon -16777216 false false 180 75 255 105 285 150 285 210 270 210 240 195 195 105 180 90
Polygon -7500403 true true 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 false false 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 true false 135 300 165 300 180 285 120 285

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

hornet
true
0
Polygon -1184463 true false 195 150 105 150 135 165 120 225 105 270 135 300 165 300 195 270 180 225 165 165 195 150
Rectangle -16777216 true false 90 165 212 185
Polygon -16777216 true false 120 210 120 225 180 225 180 210
Polygon -16777216 true false 103 266 198 266 203 246 96 246
Polygon -1184463 true false 120 150 105 135 105 75 120 60 180 60 195 75 195 135 180 150
Polygon -6459832 true false 150 15 120 30 120 60 180 60 180 30
Circle -16777216 true false 105 30 30
Circle -16777216 true false 165 30 30
Polygon -7500403 true true 120 90 75 105 15 90 30 75 120 75
Polygon -16777216 false false 120 75 30 75 15 90 75 105 120 90
Polygon -7500403 true true 180 75 180 90 225 105 285 90 270 75
Polygon -16777216 false false 180 75 270 75 285 90 225 105 180 90
Polygon -7500403 true true 180 75 180 90 195 105 240 195 270 210 285 210 285 150 255 105
Polygon -16777216 false false 180 75 255 105 285 150 285 210 270 210 240 195 195 105 180 90
Polygon -7500403 true true 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 false false 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 true false 135 300 165 300 180 285 120 285
Polygon -7500403 true true 120 210 75 225 60 255 75 240 120 225
Polygon -7500403 true true 180 210 225 225 240 255 225 240 180 225
Polygon -7500403 true true 120 75 90 60 75 30 90 45 120 60
Polygon -7500403 true true 180 75 210 60 225 30 210 45 180 60
Circle -7500403 true true 135 90 30
Rectangle -16777216 true false 105 120 195 135
Rectangle -16777216 true false 120 75 180 90
Circle -7500403 true true 135 60 30

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wasp
true
0
Polygon -1184463 true false 195 150 105 150 135 165 120 225 105 270 135 300 165 300 195 270 180 225 165 165 195 150
Rectangle -16777216 true false 90 165 212 185
Polygon -16777216 true false 120 210 120 225 180 225 180 210
Polygon -16777216 true false 103 266 198 266 203 246 96 246
Polygon -1184463 true false 120 150 105 135 105 75 120 60 180 60 195 75 195 135 180 150
Polygon -6459832 true false 150 15 120 30 120 60 180 60 180 30
Circle -16777216 true false 105 30 30
Circle -16777216 true false 165 30 30
Polygon -7500403 true true 120 90 75 105 15 90 30 75 120 75
Polygon -16777216 false false 120 75 30 75 15 90 75 105 120 90
Polygon -7500403 true true 180 75 180 90 225 105 285 90 270 75
Polygon -16777216 false false 180 75 270 75 285 90 225 105 180 90
Polygon -7500403 true true 180 75 180 90 195 105 240 195 270 210 285 210 285 150 255 105
Polygon -16777216 false false 180 75 255 105 285 150 285 210 270 210 240 195 195 105 180 90
Polygon -7500403 true true 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 false false 120 75 45 105 15 150 15 210 30 210 60 195 105 105 120 90
Polygon -16777216 true false 135 300 165 300 180 285 120 285
Polygon -7500403 true true 120 210 75 225 60 255 75 240 120 225
Polygon -7500403 true true 180 210 225 225 240 255 225 240 180 225
Polygon -7500403 true true 120 75 90 60 75 30 90 45 120 60
Polygon -7500403 true true 180 75 210 60 225 30 210 45 180 60
Circle -7500403 true true 135 90 30
Rectangle -16777216 true false 105 120 195 135
Rectangle -16777216 true false 120 75 180 90
Circle -7500403 true true 135 60 30

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
